$(function () {
    $('a.renew_captcha').click(function () {
        $.get('/ajax/callme/action_captcha/renew', function (data) {
            $('#img_captcha').remove();
            $('.captcha_img').prepend(data.image);
            $('#captcha_error').html('');
        });

        return false;
    });
});
