<?php 

$lang['title'] = 'Request from site';

$lang['display_as'] = array(
    'name' => 'Name',
    'text' => 'Message',
    'phone' => 'Phone',
    'email' => 'Email',
    'date_add' => 'Date',
    'worked_out' => 'Proccessed'
);

$lang['config_title'] = $lang['title'] . '/Configuration';


$lang['msg_ok'] = 'Saved';
$lang['btn_save'] = 'Save';

$lang['config_aliases'] = array(
    'email' => '<p><b>Email for notification.</b></p>if it is empty then email wont send',
    'subject' => '<b>Subject</b>',
    'template' => '<p><b>Template.</b></p>'
    . '<p>Variables:</p> '
    . '<p>{in_name} - Name</p>'
    . '<p>{in_email} - E-mail</p>'
    . '<p>{in_phone} - Phone</p>'
    . '<p>{in_text} - Text</p>',
);