<?php
$this->js_css->parse_js('callme/js/captcha.js');
?>
<div class="captcha_block">    
    <div class="captcha_img">
        <?= $captcha['image'] ?>
        <a href="#" class="renew_captcha"><?= $this->lang->line('ln_refresh') ?></a>
    </div>
    <input type="text" name="captcha" required placeholder="<?= $this->lang->line('ln_placeholder') ?>">
    <div id="captcha_error"></div>
</div>